@@ -21,12 +21,13 @@ test_that("select values are inherited from names", {
       <option>y</option>
     </select>
   ')
+
   opts <- page %>% html_node('select') %>% parse_select()
   expect_equal(opts$options, c(x = "1", y = "y"))
 })
 
 test_that("parse_fields gets the button", {
-    select <- minimal_html("button test", '
+  select <- minimal_html("button test", '
     <form>
       <button type="submit">Click me</button>
     </form>
@@ -35,3 +36,21 @@ test_that("parse_fields gets the button", {
   form <- select %>% html_node("form") %>% html_form()
   expect_equal(form$fields[[1]]$type, "submit")
 })
+
+test_that("submit_request detects submit-buttons correct", {
+  select <- minimal_html("submit test", '
+    <form id="suchparameterForm" method="post" action="/test-path">
+      <select name="elementWithoutType" size="1">
+        <option value="10">10</option>
+        <option value="25">25</option>
+      </select>
+    <button type="submit" name="clickMe">Click me</button>
+    </form>
+  ')
+  form <- select %>% html_node("form") %>% html_form()
+
+  req <- submit_request(form, "clickMe")
+  expect_length(req, 4L)
+  expect_equal(req$method, "POST")
+  expect_equal(req$url, "/test-path")
+})
